# String format build errors are mostly avoided by gcc stupidity
# Only few are usually fixed by patches, it makes no sense.
# So disable check at all.
%define Werror_cflags %{nil}

%bcond_without cycles

Summary:	A fully functional 3D modeling/rendering/animation package
Name:		blender
Version:	2.70a
Release:	5
License:	GPLv2+
Group:		Graphics
Url:		http://www.blender.org/
Source0:	http://download.blender.org/source/%{name}-%{version}.tar.gz
Source100:	blender.rpmlintrc
Patch0:		blender-2.67-localedir.patch
Patch1:		blender-2.60-error-when-missing-sse.patch
Patch2:		blender-2.58-static-lib.patch
Patch3:		blender-2.65-openjpeg_stdbool.patch
# Cycles build fails with undefined reference error as libs are build as shared
Patch5:		blender-2.70a-cycles-static.patch
# Patch submitted upstream - Blender Patches item #19234,
Patch6:		blender-2.67-uninit-var.patch

BuildRequires:	cmake >= 2.8
BuildRequires:	boost-devel
BuildRequires:	ffmpeg-devel >= 0.7
BuildRequires:	gomp-devel
BuildRequires:	jpeg-devel
BuildRequires:	openjpeg-devel
BuildRequires:	tiff-devel
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(freetype2)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(openal)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(samplerate)
BuildRequires:	pkgconfig(sndfile)
BuildRequires:	pkgconfig(sdl)
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(xi)
%if %{with cycles}
BuildRequires:	OpenImageIO-devel
BuildRequires:	OpenColorIO-devel
%endif
Requires:	python3 >= 3.3

%description
Blender is the in-house software of a high quality animation studio.
It has proven to be an extremely fast and versatile design instrument.
The software has a personal touch, offering a unique approach to the
world of three dimensions. Blender can be used to create TV
commercials, to make technical visualizations or business graphics, to
do some morphing, or to design user interfaces. Developers can easily
build and manage complex environments. The renderer is versatile and
extremely fast. All basic animation principles (curves and keys) are
implemented.

%files
%doc release/text/*
%{_bindir}/*
%{_datadir}/applications/*.desktop
%{_datadir}/%{name}
%{_mandir}/man1/%{name}.1.*
%{_iconsdir}/hicolor/*/apps/%{name}.*

%post
if [ -x %{_gconftool_bin} ]; then
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --type boolean --set /desktop/gnome/thumbnailers/application@x-blender/enable true
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --type string --set /desktop/gnome/thumbnailers/application@x-blender/command "blender-thumbnailer.py %u %o"
fi

%preun
if [ "$1" = "0" -a -x %{_gconftool_bin} ]; then
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --unset /desktop/gnome/thumbnailers/application@x-blender/enable
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --unset /desktop/gnome/thumbnailers/application@x-blender/command
fi

#----------------------------------------------------------------------------

%prep
%setup -q -n %{name}-v%{version}
#patch0 -p1 -b .localedir
%patch1 -p0 -b .sse
%patch2 -p0 -b .static
%patch3 -p1 -b .openjpeg
%patch5 -p1 -b .cycles-static
%patch6 -p1

%build
%ifarch %{ix86}
# build non-sse flavour
%cmake \
	-DWITH_INSTALL_PORTABLE:BOOL=OFF \
	-DWITH_PLAYER:BOOL=ON \
	-DWITH_PYTHON:BOOL=ON \
	-DPYTHON_VERSION:STRING=%{py3_ver} \
	-DWITH_PYTHON_INSTALL:BOOL=OFF \
	-DWITH_BUILTIN_GLEW:BOOL=OFF \
	-DWITH_CODEC_FFMPEG:BOOL=ON \
	-DWITH_CODEC_SNDFILE:BOOL=ON \
	-DWITH_FFTW3:BOOL=ON \
	-DWITH_MOD_OCEANSIM:BOOL=ON \
	-DWITH_IMAGE_REDCODE:BOOL=ON \
	-DOPENJPEG_ROOT_DIR=/usr/include/openjpeg-1.5 \
%if %{with cycles}
	-DWITH_CYCLES:BOOL=ON \
%else
	-DWITH_CYCLES:BOOL=OFF \
%endif
	-DWITH_RAYOPTIMIZATION:BOOL=OFF
%make
cd ..
mv build non-sse
%endif

#build sse flavour
%cmake \
	-DWITH_INSTALL_PORTABLE:BOOL=OFF \
	-DWITH_PLAYER:BOOL=ON \
	-DWITH_PYTHON:BOOL=ON \
	-DPYTHON_VERSION:STRING=%{py3_ver} \
	-DWITH_PYTHON_INSTALL:BOOL=OFF \
	-DWITH_BUILTIN_GLEW:BOOL=OFF \
	-DWITH_CODEC_FFMPEG:BOOL=ON \
	-DWITH_CODEC_SNDFILE:BOOL=ON \
	-DWITH_FFTW3:BOOL=ON \
	-DWITH_MOD_OCEANSIM:BOOL=ON \
	-DWITH_IMAGE_REDCODE:BOOL=ON \
	-DOPENJPEG_ROOT_DIR=/usr/include/openjpeg-1.5 \
%if %{with cycles}
	-DWITH_CYCLES:BOOL=ON \
%else
	-DWITH_CYCLES:BOOL=OFF \
%endif
	-DWITH_RAYOPTIMIZATION:BOOL=ON
%make

%install
#install sse flavour
%makeinstall_std -C build

# Install hicolor icons.
for i in 16x16 22x22 32x32 48x48 256x256 ; do
  mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${i}/apps
  install -pm 0644 release/freedesktop/icons/${i}/apps/%{name}.png \
    %{buildroot}%{_datadir}/icons/hicolor/${i}/apps/%{name}.png
done

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps
install -pm 0644 release/freedesktop/icons/scalable/apps/%{name}.svg \
    %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%ifarch %{ix86}
mv %{buildroot}%{_bindir}/%{name} %{buildroot}%{_bindir}/%{name}.sse

#install non-sse flavour
rm -fr build
mv non-sse build
%makeinstall_std -C build
mv %{buildroot}%{_bindir}/%{name} %{buildroot}%{_bindir}/%{name}.nonsse

# install wrapper
cat >> %{buildroot}%{_bindir}/blender <<EOF 
if [ -e /proc/cpuinfo ]; then
	SSE="\`cat /proc/cpuinfo | grep flags | grep sse\`"
fi

if [ "x\$SSE" == x ]; then
	%{_bindir}/%{name}.nonsse "\$@"
else
	%{_bindir}/%{name}.sse "\$@"
fi
EOF
chmod 0755 %{buildroot}%{_bindir}/blender
%endif

sed -i -e 's,#!/usr/bin/python,#!/usr/bin/python3,' %{buildroot}%{_bindir}/blender-thumbnailer.py %{buildroot}%{_datadir}/%{name}/*/scripts/modules/blend_render_info.py


%changelog
* Fri Jun 27 2014 Alex Burmashev <alex.burmashev@rosalab.ru> 2.70a-5
+ Revision: 2f5aad9
- MassBuild#440: Increase release tag

* Thu Jun 26 2014 Denis Silakov <denis.silakov@rosalab.ru> 2.70a-4
+ Revision: 729e236
- Add DPYTHON_VERSION

* Wed Jun 25 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.70a-4
+ Revision: 7d1aa60
- Bump release

* Thu Jun 19 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.70a-3
+ Revision: b8f8dac
- Bump release

* Wed Jun 18 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.70a-2
+ Revision: d0a1b72
- New version 2.70a, try not to use localedir patch

* Tue Jun 03 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.69-3
+ Revision: f17fab5
- MassBuild#430: Increase release tag

* Tue Dec 17 2013 Alexander Kazancev <kazancas@gmail.com> 2.69-2
+ Revision: 3362474
- Rebuild with libglew

* Sun Nov 17 2013 RA <oeai@symbiants.com> 2.69-1
+ Revision: 74b94bb
- v 69 blender.spec

* Sun Nov 17 2013 RA <oeai@symbiants.com> 2.68a-1
+ Revision: d255977
- v 69

* Thu Aug 22 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.68a-1
+ Revision: db6be4a
- LOG Update BuildRequires

* Thu Aug 22 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.68a-1
+ Revision: 073ddcd
- LOG New version 2.68a

* Wed Aug 14 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.67-3
+ Revision: ab96cd1
- LOG Rebuild with new ffmpeg

* Thu Aug 01 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.67-2
+ Revision: 94da64d
- LOG Rebuild with new ffmpeg

* Mon May 13 2013 Denis Silakov <denis.silakov@rosalab.ru> 2.67-1
+ Revision: 0608d3c
- Added missing patch

* Mon May 13 2013 Denis Silakov <denis.silakov@rosalab.ru> 2.67-1
+ Revision: 6440bb2
- LOG Updated to 2.67

* Fri Mar 15 2013 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.66a-1
+ Revision: 4ef48a0
- LOG New version 2.66a, merge cleanups with Cooker, re-diff some patches, disable string format security check as it's useless here

* Wed Feb 20 2013 root <root@localhost.localdomain> 2.65a-1
+ Revision: db90be3
- update to 2.65a

* Sun Oct 07 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.64-3
+ Revision: d9fa16e
- LOG Use better patch for system locales

* Sat Oct 06 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.64-2
+ Revision: 87c0854
- LOG Add patch to fix Cycles build, build with fftw3 support

* Fri Oct 05 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.64-1
+ Revision: 8eafbd3
- Drop old patch

* Fri Oct 05 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.64-1
+ Revision: cdb58a6
- Update syspath patch

* Fri Oct 05 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.64-1
+ Revision: ed9e3a3
- Update sfmt patch

* Fri Oct 05 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.64-1
+ Revision: e059aa2
- LOG Add patch to fix string not format literal error, fix one more typo, add openjpeg root dir to cmake options

* Fri Oct 05 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.64-1
+ Revision: 1506c75
- Fix typo, minor cosmetic update

* Fri Oct 05 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.64-1
+ Revision: f83c7b8
- LOG Build without Cycles support for now

* Fri Oct 05 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.64-1
+ Revision: fc2490e
- LOG Update uninit-var patch

* Fri Oct 05 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.64-1
+ Revision: 81246de
- LOG Drop no longer needed patches

* Fri Oct 05 2012 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.64-1
+ Revision: 7902020
- LOG New version 2.64

* Tue May 08 2012 Rosa <rosa@rosa-build.rosalab.ru> 2.63-1
+ Revision: b034a4e
- Automatic import for version 2.63

* Mon Feb 20 2012 Rosa <rosa@rosa-build.rosalab.ru> 2.62-2
+ Revision: 9aa2118
- Automatic import for version 2.62

* Wed Feb 01 2012 Rosa <rosa@rosa-build.rosalab.ru> 2.61-1
+ Revision: 6bdd746
- Automatic import for version 2.61


